Re-export from bsql-arena — the arena is a shared crate used by all drivers.
Structs
- Arena
- A bump allocator for row data.
- Arena
Rows - A collection of decoded rows backed by an arena.
- Validated
Rows - A collection of decoded rows with batch-validated text data.
Functions
- acquire_
arena - Acquire an arena from the thread-local pool, or create a new one.
- release_
arena - Return an arena to the thread-local pool for reuse.