Single-source OID mapping: Rust type string -> PostgreSQL OID.
This is the canonical source of truth for the Rust type -> PG OID mapping.
bsql-core::types::default_pg_oid_for_rust_type delegates to this function.
Functions
- default_
pg_ oid_ for_ rust_ type - Map a Rust type string to the default PostgreSQL OID for that type.