Module arena

Module arena 

Re-export from bsql-arena — the arena is a shared crate used by all drivers.

Structs

Arena
A bump allocator for row data.
ArenaRows
A collection of decoded rows backed by an arena.
ValidatedRows
A collection of decoded rows with batch-validated text data.

Functions

acquire_arena
Acquire an arena from the thread-local pool, or create a new one.
release_arena
Return an arena to the thread-local pool for reuse.