Module oid_map

Module oid_map 

Single-source OID mapping: Rust type string -> PostgreSQL OID.

This is the canonical source of truth for the Rust type -> PG OID mapping. bsql-core::types::default_pg_oid_for_rust_type delegates to this function.

Functions

default_pg_oid_for_rust_type
Map a Rust type string to the default PostgreSQL OID for that type.